@@ -1,4 +1,4 @@
-/*	$Id: kcgi.h,v 1.87 2016/03/10 05:45:21 kristaps Exp $ */
+/*	$Id: kcgi.h,v 1.96 2017/03/12 06:01:29 kristaps Exp $ */
 /*
  * Copyright (c) 2012, 2014, 2015, 2016 Kristaps Dzonsons <kristaps@bsd.lv>
  *
@@ -433,7 +433,14 @@ struct	ktemplate {
 	const char *const	 *key;
 	size_t		 	  keysz;
 	void		 	 *arg;
-	int		 	(*cb)(size_t key, void *arg);
+	int		 	(*cb)(size_t, void *);
+};
+
+typedef int (*ktemplate_writef)(const char *, size_t, void *);
+
+struct	ktemplatex {
+	ktemplate_writef	 writer;
+	int			(*fbk)(const char *, size_t, void *);
 };
 
 enum	kcgi_err {
@@ -454,14 +461,13 @@ enum	kcgi_err {
 
 __BEGIN_DECLS
 
-typedef int	(*ktemplate_writef)(const char *, size_t, void *);
-
 int		 khttp_body(struct kreq *);
 int		 khttp_body_compress(struct kreq *, int);
 void		 khttp_free(struct kreq *);
 void		 khttp_child_free(struct kreq *);
-void		 khttp_head(struct kreq *, const char *, const char *,
-			...) __attribute__((format(printf, 3, 4)));
+void		 khttp_head(struct kreq *, const char *, 
+			const char *, ...) 
+			__attribute__((format(printf, 3, 4)));
 enum kcgi_err	 khttp_parse(struct kreq *, 
 			const struct kvalid *, size_t,
 			const char *const *, size_t, size_t);
@@ -476,11 +482,15 @@ void		 khttp_puts(struct kreq *, const char *);
 int		 khttp_template(struct kreq *, 
 			const struct ktemplate *, const char *);
 int		 khttp_template_buf(struct kreq *, 
-			const struct ktemplate *, const char *, size_t);
+			const struct ktemplate *, const char *, 
+			size_t);
 int		 khttp_templatex(const struct ktemplate *, 
-			const char *, ktemplate_writef, void *);
+			const char *, const struct ktemplatex *, 
+			void *);
 int		 khttp_templatex_buf(const struct ktemplate *, 
-			const char *, size_t, ktemplate_writef, void *);
+			const char *, size_t, 
+			const struct ktemplatex *, void *);
+
 void		 khttp_write(struct kreq *, const char *, size_t);
 
 int		 khttpdigest_validate(const struct kreq *, 
@@ -514,6 +524,24 @@ enum kcgi_err	 khttp_fcgi_free(struct kfcgi *);
 void		 khttp_fcgi_child_free(struct kfcgi *);
 int		 khttp_fcgi_test(void);
 
+#define		KUTIL_EPOCH2TM(_tt, _tm) \
+		kutil_epoch2tmvals((_tt), \
+			&(_tm)->tm_sec, \
+			&(_tm)->tm_min, \
+			&(_tm)->tm_hour, \
+			&(_tm)->tm_mday, \
+			&(_tm)->tm_mon, \
+			&(_tm)->tm_year, \
+			&(_tm)->tm_wday, \
+			&(_tm)->tm_yday);
+void		 kutil_epoch2tmvals(int64_t, int *, int *, int *, 
+			int *, int *, int *, int *, int *);
+char		*kutil_epoch2str(int64_t, char *, size_t);
+char		*kutil_epoch2utcstr(int64_t, char *, size_t);
+int64_t	 	 kutil_date2epoch(int64_t, int64_t, int64_t);
+int64_t	 	 kutil_datetime2epoch(int64_t, int64_t, int64_t,
+			int64_t, int64_t, int64_t);
+
 char		*kutil_urlabs(enum kscheme, const char *, 
 			uint16_t, const char *);
 char		*kutil_urlpart(struct kreq *, const char *,
@@ -523,7 +551,35 @@ char		*kutil_urlpartx(struct kreq *, const char *,
 char		*kutil_urlencode(const char *);
 void		 kutil_invalidate(struct kreq *, struct kpair *);
 
-int		 kasprintf(char **, const char *, ...);
+int		 kutil_openlog(const char *);
+void		 kutil_vinfo(const struct kreq *, 
+			const char *, const char *, va_list);
+void		 kutil_vlog(const struct kreq *, const char *,
+			const char *, const char *, va_list);
+void		 kutil_vlogx(const struct kreq *, const char *,
+			const char *, const char *, va_list);
+void		 kutil_vwarn(const struct kreq *, 
+			const char *, const char *, va_list);
+void		 kutil_vwarnx(const struct kreq *, 
+			const char *, const char *, va_list);
+void		 kutil_log(const struct kreq *, const char *,
+			const char *, const char *, ...)
+			__attribute__((format(printf, 4, 5)));
+void		 kutil_logx(const struct kreq *, const char *,
+			const char *, const char *, ...)
+			__attribute__((format(printf, 4, 5)));
+void		 kutil_info(const struct kreq *, 
+			const char *, const char *, ...)
+			__attribute__((format(printf, 3, 4)));
+void		 kutil_warn(const struct kreq *, 
+			const char *, const char *, ...)
+			__attribute__((format(printf, 3, 4)));
+void		 kutil_warnx(const struct kreq *, 
+			const char *, const char *, ...)
+			__attribute__((format(printf, 3, 4)));
+
+int		 kasprintf(char **, const char *, ...)
+			__attribute__((format(printf, 2, 3)));
 void		*kcalloc(size_t, size_t);
 void		*kmalloc(size_t);
 void		*krealloc(void *, size_t);
