@@ -1,4 +1,4 @@
-/*	$Id: kcgihtml.h,v 1.5 2016/03/10 05:45:21 kristaps Exp $ */
+/*	$Id: kcgihtml.h,v 1.6 2016/10/04 20:04:37 kristaps Exp $ */
 /*
  * Copyright (c) 2012, 2014, 2015 Kristaps Dzonsons <kristaps@bsd.lv>
  *
@@ -458,6 +458,8 @@ struct	khtmlreq {
 	enum kelem	 elems[KDATA_MAXELEMSZ];
 	size_t		 elemsz;
 	int		 newln;
+	int		 opts;
+#define	KHTML_PRETTY	 0x01
 };
 
 __BEGIN_DECLS
@@ -473,7 +475,7 @@ size_t		 khtml_elemat(struct khtmlreq *);
 void		 khtml_entity(struct khtmlreq *, enum kentity);
 void		 khtml_int(struct khtmlreq *, int64_t);
 void		 khtml_ncr(struct khtmlreq *, uint16_t);
-void		 khtml_open(struct khtmlreq *, struct kreq *);
+void		 khtml_open(struct khtmlreq *, struct kreq *, int);
 void		 khtml_putc(struct khtmlreq *, char);
 void		 khtml_puts(struct khtmlreq *, const char *);
 void		 khtml_text(struct khtmlreq *, const char *)
